@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/chown.c,v 1.12 2004/03/21 14:13:11 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/chown.c,v 1.13 2005/01/22 16:32:29 werner Exp $
  *
  * Change Owner
  *
@@ -42,7 +42,7 @@ int ChangeFileOwner(FileEntry *fe_ptr)
 
 int GetNewOwner(int st_uid)
 {
-  char owner[OWNER_NAME_MAX+1];
+  char owner[OWNER_NAME_MAX * 2 +1];
   char *owner_name_ptr;
   int  owner_id;
   int  id;
