@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/login.c,v 1.20 2004/03/21 14:13:11 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/login.c,v 1.21 2005/01/22 16:32:29 werner Exp $
  *
  * Dateibaum lesen
  *
@@ -595,7 +595,7 @@ int GetNewLoginPath(char *path)
 {
   int result;
   char *cptr;
-  char aux[PATH_LENGTH + 1]= "";
+  char aux[PATH_LENGTH * 2 + 1]= "";
   
   result = -1;
 
