@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/view.c,v 1.23 2004/11/13 21:08:05 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/view.c,v 1.25 2004/12/30 18:55:32 werner Exp $
  *
  * View-Kommando-Bearbeitung
  *
@@ -30,6 +30,8 @@ static WINDOW *VIEW, *BORDER;
 
 BOOL inhex=TRUE;
 BOOL inedit=FALSE;
+BOOL hexoffset=TRUE;
+
 
 #define CURSOR_CALC_X (10+((cursor_pos_x<(BYTES))? 2:3)+(cursor_pos_x)+(cursor_pos_x/2))
 #define CURSOR_POS_X ((inhex)? CURSOR_CALC_X:(WCOLS-BYTES+cursor_pos_x))
@@ -277,7 +279,11 @@ void printhexline(WINDOW *win, char *line, char *buf, int r, long offset)
 	wclrtoeol(win);
 	return;
     }
-    sprintf(line, "%010d  ", (int)offset);
+    if(hexoffset) {
+      sprintf(line, "%010X  ", (int)offset);
+    } else {
+      sprintf(line, "%010d  ", (int)offset);
+    }
     for (i = 1; i <= r; i++ ) 
     {
         if ((i == (BYTES / 2) ) || (i == BYTES ))
@@ -318,7 +324,7 @@ void update_line(WINDOW *win, long line)
     line_string[0] = '\0';
     buf = (char *) xmalloc(BYTES);
     memset(buf, ' ', BYTES);
-    if (lseek(fd, line * BYTES, SEEK_SET)== -1 )
+    if (lseek(fd, (line - 1) * BYTES, SEEK_SET)== -1 )
     {
         sprintf(mensaje, "Error %ld ", line);
 	perror(mensaje);
@@ -470,7 +476,7 @@ void change_char(int ch)
     char mensaje[50];
     
     cambio = malloc(sizeof(struct MODIF));
-    cambio -> pos = ( (cursor_pos_y + current_line) * BYTES) + CURSOR_POSX;
+    cambio -> pos = ( (cursor_pos_y + current_line - 1) * BYTES) + CURSOR_POSX;
     if (lseek(fd, cambio -> pos, SEEK_SET)== -1 )
     {
         sprintf(mensaje,"Error %s ", strerror(errno));
@@ -538,13 +544,13 @@ void move_right(WINDOW *win)
 {
    fstat(fd,&fdstat);
    cursor_pos_x++;
-   if (fdstat.st_size > ((cursor_pos_y+current_line) * BYTES + CURSOR_POSX )){
+   if (fdstat.st_size > ((cursor_pos_y+current_line-1) * BYTES + CURSOR_POSX )){
 	cursor_pos_x--;
 	if ( cursor_pos_x < CANTX(BYTES) - 1 ) {
     	    cursor_pos_x += 1;
 	    wmove( win, cursor_pos_y, CURSOR_POS_X);
 	}else {
-	    if (fdstat.st_size >= ((current_line+1+cursor_pos_y) * BYTES) ){
+	    if (fdstat.st_size >= ((current_line+cursor_pos_y) * BYTES) ){
 		if (cursor_pos_y < WLINES-1 ) {
 		    cursor_pos_y++;
 		    cursor_pos_x = 0;
@@ -612,23 +618,40 @@ void hex_edit(char *file_path)
 		      break;
 	    case KEY_DOWN: /*ScrollDown();*/
 			   fstat(fd,&fdstat);
-			   if (fdstat.st_size > ((cursor_pos_y + 1 +
-					current_line) * BYTES + CURSOR_POSX))
-				if (cursor_pos_y < WLINES-1){
-				    wmove( VIEW, ++cursor_pos_y, CURSOR_POS_X);
-				    wnoutrefresh(VIEW);
+			   if (fdstat.st_size > ((cursor_pos_y + current_line - 1) * BYTES + CURSOR_POSX)) {
+
+			   	if (fdstat.st_size > ((cursor_pos_y + current_line - 1 + 1) * BYTES + CURSOR_POSX)) {
+					
+					if (cursor_pos_y < WLINES-1){
+				    		wmove( VIEW, ++cursor_pos_y, CURSOR_POS_X);
+				    		wnoutrefresh(VIEW);
+					} else {
+				    		++current_line;
+				    		scroll_down(VIEW);
+				    		wmove( VIEW, cursor_pos_y, CURSOR_POS_X);
+				    		wnoutrefresh(VIEW);
+					}
 				} else {
-				    /*oldpos = current_line * BYTES;*/
-				    ++current_line;
-				    scroll_down(VIEW);
-				    if (fdstat.st_size < ((cursor_pos_y +
-					current_line) * BYTES + CURSOR_POSX) )
-					cursor_pos_y = 0;
-				    wmove( VIEW, cursor_pos_y, CURSOR_POS_X);
-				    wnoutrefresh(VIEW);
+					/* special case: last line */
+
+					if (fdstat.st_size > ((cursor_pos_y + current_line - 1 + 1) * BYTES)) {
+						
+						for(cursor_pos_x = 0; (CURSOR_POSX + 1) < (fdstat.st_size % BYTES); cursor_pos_x++);
+
+						if (cursor_pos_y < WLINES-1){
+							wmove( VIEW, ++cursor_pos_y, CURSOR_POS_X);
+							wnoutrefresh(VIEW);
+						} else {
+							++current_line;
+							scroll_down(VIEW);
+							wmove( VIEW, cursor_pos_y, CURSOR_POS_X);
+							wnoutrefresh(VIEW);
+						}
+					}
 				}
-			    else
+			    } else {
 				beep();
+			    }
 			    break;
 	    case KEY_UP: /*ScroollUp();*/
 			if (cursor_pos_y > 0)
@@ -678,38 +701,45 @@ void hex_edit(char *file_path)
 		            break;
 	    case KEY_NPAGE: /*ScroollPageUp();*/
 			    fstat(fd,&fdstat);
-			    if (fdstat.st_size > 
-				((current_line + WLINES + 1 + cursor_pos_y) 
-				* BYTES) + CURSOR_POSX ) 
+			    if (fdstat.st_size > ((current_line - 1 + WLINES + cursor_pos_y) * BYTES) + CURSOR_POSX ) {
 				current_line += WLINES;
-			    else
-				beep();
+			    } else {
+			        int n;
+				n = fdstat.st_size / BYTES; /* numer of full lines */
+				if(fdstat.st_size % BYTES) {
+				  n++; /* plus 1 not fully used line */
+				}
+				if(current_line != n) {
+				  current_line = n;
+				  cursor_pos_y = 0;
+				  for(cursor_pos_x = 0; (CURSOR_POSX + 1) < (fdstat.st_size % BYTES); cursor_pos_x++);
+				} else {
+				  beep();
+				}
+			    }
 /*			    oldpos = current_line * BYTES;*/
 			    update_all_lines(VIEW,WLINES);
 			    wmove( VIEW, cursor_pos_y, CURSOR_POS_X);
 			    wnoutrefresh(VIEW);
 		            break;
 	    case KEY_HOME: 
-			    if (CURSOR_POSX > 0)
-			    {
+			    if (CURSOR_POSX > 0) {
 				cursor_pos_x = 0;
 				wmove( VIEW, cursor_pos_y, CURSOR_POS_X);
-			    }else
+			    } else
 				beep();
 			    wnoutrefresh(VIEW);
 	                    break;
 	    case KEY_END: 
 			 fstat(fd,&fdstat);
-			 if (fdstat.st_size < ((cursor_pos_y + current_line)
-				* BYTES + BYTES)+2 )
-			        beep();
-			 else
-			 if (cursor_pos_x < CANTX(BYTES)-1){
+			 if ( ((cursor_pos_y + current_line) * BYTES) > fdstat.st_size ) {
+			        cursor_pos_x = CANTX(fdstat.st_size % BYTES) - 1;
+			 } else {
 			    cursor_pos_x = CANTX(BYTES)-1;
-			    wmove( VIEW, cursor_pos_y, CURSOR_POS_X);
-			    wnoutrefresh(VIEW);
-			}
-	                break;
+			 }
+			 wmove( VIEW, cursor_pos_y, CURSOR_POS_X);
+			 wnoutrefresh(VIEW);
+	                 break;
 	    case '\t' :
 			/* move cursor to the the other part of the window*/
 			if (inhex){
@@ -756,6 +786,8 @@ int InternalView(char *file_path)
     int ch;
     BOOL QUIT=FALSE;
     
+    hexoffset = (!strcmp(HEXEDITOFFSET, "HEX")) ? TRUE : FALSE;
+
     if (stat(file_path, &fdstat)!=0)
 	return -1;
     if (!(S_ISREG(fdstat.st_mode)) || S_ISBLK(fdstat.st_mode))
@@ -792,7 +824,7 @@ int InternalView(char *file_path)
 		      break;
 	    case KEY_DOWN: /*ScrollDown();*/
 			   fstat(fd,&fdstat);
-			   if (fdstat.st_size > ((current_line + 1) * BYTES) )
+			   if (fdstat.st_size > (current_line * BYTES) )
 			   {
 				current_line++;
 				oldpos = current_line * BYTES;
@@ -826,11 +858,20 @@ int InternalView(char *file_path)
 	    case KEY_RIGHT:
 	    case KEY_NPAGE: /*ScroollPageUp();*/
 			    fstat(fd,&fdstat);
-			    if (fdstat.st_size > 
-				((current_line + WLINES) * BYTES) ) 
+			    if (fdstat.st_size > ((current_line - 1 + WLINES) * BYTES) ) {
 				current_line += WLINES;
-			    else
-				beep();
+			    } else {
+			        int n;
+				n = fdstat.st_size / BYTES; /* numer of full lines */
+				if(fdstat.st_size % BYTES) {
+				  n++; /* plus 1 not fully used line */
+				}
+				if(current_line != n) {
+				  current_line = n;
+				} else {
+				  beep();
+				}
+			    }
 			    oldpos = current_line * BYTES;
 			    update_all_lines(VIEW,WLINES);
 		            break;
