@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/ytree.h,v 1.41 2007/04/01 13:33:36 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/ytree.h,v 1.42 2007/06/04 16:58:03 werner Exp $
  *
  * Header-Datei fuer YTREE
  *
@@ -87,11 +87,19 @@ extern char *getcwd();
 #include <wchar.h>
 #endif
 
-#if defined(__OpenBSD__) || defined(__NetBSD__)
+#ifdef __OpenBSD__
 #define STATFS(a, b, c, d )     statfs( a, b )
 #define LONGLONG		long long
 #define HAS_LONGLONG		1
 #else
+#ifdef __NetBSD__
+#define STATFS(a, b, c, d )     statvfs( a, b )
+#define LONGLONG		long long
+#define HAS_LONGLONG		1
+#define typeahead( file )
+#define vidattr( attr )
+#define putp( str )             tputs( str, 1, putchar )
+#else
 #ifdef __APPLE__
 #define STATFS(a, b, c, d )     statfs( a, b )
 #define LONGLONG		long long
@@ -160,7 +168,8 @@ extern char *getcwd();
 #endif /* OSF1 */
 #endif /* __APPLE__ */
 #endif /* __FreeBSD__ */
-#endif /* __OpenBSD__ || __NetBSD__ */
+#endif /* __NetBSD__ */
+#endif /* __OpenBSD__ */
 
 
 /* Some handy macros... */
